@@ -1,4 +1,5 @@
 import string
+from kolibri import forms
 
 def name_from_item(item):
     """
@@ -87,6 +88,7 @@ class Processor(object):
     """
     user_exclusive = False
     only_run_once = False # v0.2.0
+    has_form = False
 
     model = None
     _text = None
@@ -156,6 +158,13 @@ class Processor(object):
         """
         return hasattr(self.execute, 'NOT_IMPLEMENTED') == False
 
+    def produce_form(self):
+        """
+        
+        """
+        form, data = self.get_form()
+        return form(prefix=self.identifier(), initial=data)
+
 
 def singleton(cls):
     """
