@@ -61,7 +61,6 @@ class ProcessRegistration(object):
         return ProcessException.on_exception(process_item, processor_identifier, exception_name)
 
 
-
 class InternalRegistration(object):
     """
 
@@ -186,6 +185,12 @@ class ProcessorRegistration(object):
         """
         return Context._processors.values()
 
+    def has_form(self, proc_identifier):
+        """
+
+        """
+        return proc_identifier in Context._processors_with_form
+
 
 class Context(object):
     """
@@ -195,8 +200,9 @@ class Context(object):
     _workflows = {}
     _processors_for_model = {}
     _workflows_for_model = {}
+    _processors_with_form = []
 
-    def __init__(self, async=False, *args, **kwargs):
+    def __init__(self, async=True, *args, **kwargs):
         """
 
         """
@@ -221,6 +227,7 @@ class Context(object):
         cls._workflows = {}
         cls._processor_for_model = {}
         cls._workflow_for_models = {}
+        cls._processors_with_form = []
 
     @classmethod
     def register_processor(cls, processor):
@@ -230,6 +237,9 @@ class Context(object):
         if not processor.identifier() in cls._processors:
             cls._processors[processor.identifier()] = processor
 
+        if processor.has_form:
+            cls._processors_with_form.append(processor.identifier())
+
         if processor.model:
             instance_name = name_from_item(processor.model)
             if not instance_name in cls._processors_for_model:
@@ -249,3 +259,10 @@ class Context(object):
             if not instance_name in cls._workflows_for_model:
                 cls._workflows_for_model[instance_name] = []
             cls._workflows_for_model[instance_name].append(workflow)
+
+    @classmethod
+    def has_form(cls, processor_identifier):
+        """
+
+        """
+        return processor_identifier in [p.identifier for p in cls._processors_with_form]
\ No newline at end of file
