@@ -106,7 +106,8 @@ def executor(process, **kwargs):
     try:
         warnings = 0
         for process_item in process.items.all():
-            if not handle_process_item(process, process_item, **kwargs):
+            data = kwargs.get(process_item.processor_identifier, {})
+            if not handle_process_item(process, process_item, **data):
                 warnings += 1
 
         process.result = warnings and ProcessResult.finished_with_warnings or ProcessResult.success
